==> pantsbuild.pants-1.30.0-cp36-cp36m-manylinux2014_x86_64.whl: pants/backend/python/lint/python_fmt.py <==
# Copyright 2019 Pants project contributors (see CONTRIBUTORS.md).
# Licensed under the Apache License, Version 2.0 (see LICENSE).

from dataclasses import dataclass
from typing import Iterable, List, Type

from pants.backend.python.target_types import PythonSources
from pants.core.goals.fmt import FmtResult, LanguageFmtResults, LanguageFmtTargets
from pants.core.goals.style_request import StyleRequest
from pants.core.util_rules.determine_source_files import AllSourceFilesRequest, SourceFiles
from pants.engine.fs import Digest, Snapshot
from pants.engine.rules import rule
from pants.engine.selectors import Get
from pants.engine.unions import UnionMembership, UnionRule, union


@dataclass(frozen=True)
class PythonFmtTargets(LanguageFmtTargets):
    required_fields = (PythonSources,)


@union
class PythonFmtRequest(StyleRequest):
    pass


@rule
async def format_python_target(
    python_fmt_targets: PythonFmtTargets, union_membership: UnionMembership
) -> LanguageFmtResults:
    targets_with_origins = python_fmt_targets.targets_with_origins
    original_sources = await Get[SourceFiles](
        AllSourceFilesRequest(
            target_with_origin.target[PythonSources]
            for target_with_origin in python_fmt_targets.targets_with_origins
        )
    )
    prior_formatter_result = original_sources.snapshot

    results: List[FmtResult] = []
    fmt_request_types: Iterable[Type[PythonFmtRequest]] = union_membership.union_rules[
        PythonFmtRequest
    ]
    for fmt_request_type in fmt_request_types:
        result = await Get[FmtResult](
            PythonFmtRequest,
            fmt_request_type(
                (
                    fmt_request_type.field_set_type.create(target_with_origin)
                    for target_with_origin in targets_with_origins
                ),
                prior_formatter_result=prior_formatter_result,
            ),
        )
        if result != FmtResult.noop():
            results.append(result)
        if result.did_change:
            prior_formatter_result = await Get[Snapshot](Digest, result.output)
    return LanguageFmtResults(
        tuple(results),
        input=original_sources.snapshot.digest,
        output=prior_formatter_result.digest,
    )


def rules():
    return [format_python_target, UnionRule(LanguageFmtTargets, PythonFmtTargets)]

==> pantsbuild.pants-2.0.0-cp36-cp36m-manylinux2014_x86_64.whl: pants/backend/python/lint/python_fmt.py <==
# Copyright 2019 Pants project contributors (see CONTRIBUTORS.md).
# Licensed under the Apache License, Version 2.0 (see LICENSE).

from dataclasses import dataclass
from typing import Iterable, List, Type

from pants.backend.python.target_types import PythonSources
from pants.core.goals.fmt import FmtResult, LanguageFmtResults, LanguageFmtTargets
from pants.core.goals.style_request import StyleRequest
from pants.core.util_rules.source_files import SourceFiles, SourceFilesRequest
from pants.engine.fs import Digest, Snapshot
from pants.engine.rules import Get, collect_rules, rule
from pants.engine.unions import UnionMembership, UnionRule, union


@dataclass(frozen=True)
class PythonFmtTargets(LanguageFmtTargets):
    required_fields = (PythonSources,)


@union
class PythonFmtRequest(StyleRequest):
    pass


@rule
async def format_python_target(
    python_fmt_targets: PythonFmtTargets, union_membership: UnionMembership
) -> LanguageFmtResults:
    original_sources = await Get(
        SourceFiles,
        SourceFilesRequest(target[PythonSources] for target in python_fmt_targets.targets),
    )
    prior_formatter_result = original_sources.snapshot

    results: List[FmtResult] = []
    fmt_request_types: Iterable[Type[PythonFmtRequest]] = union_membership.union_rules[
        PythonFmtRequest
    ]
    for fmt_request_type in fmt_request_types:
        result = await Get(
            FmtResult,
            PythonFmtRequest,
            fmt_request_type(
                (
                    fmt_request_type.field_set_type.create(target)
                    for target in python_fmt_targets.targets
                ),
                prior_formatter_result=prior_formatter_result,
            ),
        )
        results.append(result)
        if result.did_change:
            prior_formatter_result = await Get(Snapshot, Digest, result.output)
    return LanguageFmtResults(
        tuple(results),
        input=original_sources.snapshot.digest,
        output=prior_formatter_result.digest,
    )


def rules():
    return [*collect_rules(), UnionRule(LanguageFmtTargets, PythonFmtTargets)]
